# astropixie-widgets

*Robust, general astronomy widgets*

`astropixie-widgets` is python based library of widgets for Astronomy. Created by LSST EPO to support it's formal education Jupyter notebooks system.

Notebooks
---------

The notebooks can be found in the [investigations](https://github.com/lsst-epo/hr-diagram-investigations) repository.

Install
-------

```
pip install astropixie-widgets
```

`hr` module
-----------

Simple analysis and visualizations to create [Hertzsprung-Russell (HR) Diagrams](https://en.wikipedia.org/wiki/Hertzsprung%E2%80%93Russell_diagram).

License
-------

The MIT License. See the [LICENSE file](https://github.com/lsst-epo/vela/blob/master/LICENSE).